package com.bipt.intelligentapplicationorchestrationservice.controller;

import com.bipt.intelligentapplicationorchestrationservice.pojo.ModelLogVO;
import com.bipt.intelligentapplicationorchestrationservice.pojo.OptResult;
import com.bipt.intelligentapplicationorchestrationservice.service.EvaluationService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Tag(name = "模型评估相关接口")
@RestController
@RequestMapping("/evaluation")
@Slf4j
public class EvaluationController {
    @Autowired
    private EvaluationService evaluationService;

    /**
     * 获取日志详情
     * @param id
     * @return
     */
    @Operation(summary = "模型日志信息显示")
    @GetMapping("/detail")
    public OptResult detail(Long id){
        log.info("模型日志信息显示id:{}", id);
        ModelLogVO modelLogVO = evaluationService.detail(id);
        return OptResult.success(modelLogVO);
    }

    /**
     * 模型评估状态，评估通过则上线(1.上线，0.下线)
     * @return
     */
    @Operation(summary = "模型评估接口")
    @PutMapping("/evaluate")
    public OptResult evaluate(Long id, Integer status){
        log.info("模型上线状态修改：id:{}, status:{}", id, status);
        evaluationService.startOrStop(id, status);
        return OptResult.success();
    }
}
