package com.bipt.intelligentapplicationorchestrationservice.service.Impl;

import com.bipt.intelligentapplicationorchestrationservice.mapper.AlgorithmInfoMapper;
import com.bipt.intelligentapplicationorchestrationservice.pojo.AlgorithmInfo;
import com.bipt.intelligentapplicationorchestrationservice.service.AlgorithmInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class AlgorithmInfoServiceImpl implements AlgorithmInfoService {

    @Autowired
    private AlgorithmInfoMapper algorithmInfoMapper;

    @Override
    public AlgorithmInfo getById(Long id) {
        return algorithmInfoMapper.selectById(id);
    }

    @Override
    public AlgorithmInfo getByName(String algorithmName) {
        return algorithmInfoMapper.selectByName(algorithmName);
    }

    @Override
    public List<AlgorithmInfo> getByType(String algorithmType) {
        return algorithmInfoMapper.selectByType(algorithmType);
    }

    @Override
    @Transactional
    public boolean update(AlgorithmInfo algorithmInfo) {
        if (!validateAlgorithmInfo(algorithmInfo)) {
            return false;
        }
        return algorithmInfoMapper.update(algorithmInfo) > 0;
    }

    @Override
    @Transactional
    public boolean delete(Long id) {
        return algorithmInfoMapper.deleteById(id) > 0;
    }

    @Override
    public boolean validateAlgorithmInfo(AlgorithmInfo algorithmInfo) {
        if (algorithmInfo == null) {
            return false;
        }
        
        if (!StringUtils.hasText(algorithmInfo.getAlgorithmName()) ||
            !StringUtils.hasText(algorithmInfo.getAlgorithmFile()) ||
            !StringUtils.hasText(algorithmInfo.getAlgorithmType())) {
            return false;
        }
        
        return true;
    }
} 